# pbest

[![Release](https://img.shields.io/github/v/release/biosimulators/bsedic)](https://img.shields.io/github/v/release/biosimulators/bsedic)
[![Build status](https://img.shields.io/github/actions/workflow/status/biosimulators/bsedic/main.yml?branch=main)](https://github.com/biosimulators/bsedic/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/biosimulators/bsedic)](https://img.shields.io/github/commit-activity/m/biosimulators/bsedic)
[![License](https://img.shields.io/github/license/biosimulators/bsedic)](https://img.shields.io/github/license/biosimulators/bsedic)

pbest is a BioSimulators project designed to allow users to transform their
biological experiments written in Sed into Process-Bigraph simulations.
